==> cscec5b-xell-impl-3.0.1-20230302.024655-56-sources.jar: com/ejianc/business/wzxt/controller/StandingBookController.java <==
package com.ejianc.business.wzxt.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.wzxt.bean.ReviewDetailEntity;
import com.ejianc.business.wzxt.service.ICauseService;
import com.ejianc.business.wzxt.service.IReviewDetailService;
import com.ejianc.business.wzxt.vo.CauseDetailVO;
import com.ejianc.business.wzxt.vo.CauseRtVO;
import com.ejianc.business.wzxt.vo.CauseVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

import static com.ejianc.framework.skeleton.template.BaseServiceImpl.changeToQueryWrapper;

/**
 * 限额领料台账
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("standingBook")
public class StandingBookController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;

    @Autowired
    private IOrgApi orgApi;

    private static final String WJ_WZXT_CAUSE = "CAUSE_CODE";

    @Autowired
    private IReviewDetailService reviewDetailService;

    @Autowired
    private ICauseService causeService;

    @Autowired
    private SessionManager sessionManager;



    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("spec");
        fuzzyFields.add("materialName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
        } else {
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                    InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        Page<CauseDetailVO> page = new Page<>((long)param.getPageIndex(), (long)param.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(param);
        List<CauseDetailVO> list = reviewDetailService.queryStandingBook(page, wrapper);
        for(int i = 0;i < list.size(); i++){
            list.get(i).setId((long)i);
        }
        List<CauseRtVO> causeList = causeService.querCauseList(wrapper);
        Map<String,CauseRtVO> maps = causeList.stream().collect(Collectors.toMap(x->x.getProjectId() + x.getMaterialCode() + x.getMaterialId() + x.getConstructionDetail() + x.getSpec() + x.getUnit(), Function.identity(),(k1,k2) ->k2));
        CauseRtVO cvo;
        String k;
        for (CauseDetailVO vo : list) {
            k = vo.getProjectId() + vo.getMaterialCode() + vo.getMaterialId() + vo.getConstructionDetail() + vo.getSpec() + vo.getUnit();
            if (!maps.containsKey(k)){
                continue;
            }
            cvo = maps.get(k);
            vo.setDutyPersonDetailName(cvo.getDutyPersonDetailName());
            vo.setDutySectionDetail(cvo.getDutySectionDetail());
            vo.setExceedCauseDetail(cvo.getExceedCauseDetail());
            vo.setImprovementMeasureDetail(cvo.getImprovementMeasureDetail());
        }

        JSONObject res = new JSONObject();
        res.put("records", list);
        res.put("total", page.getTotal());
        res.put("current", page.getCurrent());
        res.put("size", page.getSize());
        res.put("pages", page.getPages());
        return CommonResponse.success("查询列表数据成功！", res);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
        } else {
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                    InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        Page<CauseDetailVO> page = new Page<>((long)param.getPageIndex(), (long)param.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(param);
        List<CauseDetailVO> list = reviewDetailService.queryStandingBookExport(wrapper);
        List<CauseRtVO> causeList = causeService.querCauseList(wrapper);
        Map<String,CauseRtVO> maps = causeList.stream().collect(Collectors.toMap(x->x.getProjectId() + x.getMaterialCode() + x.getMaterialId() + x.getConstructionDetail() + x.getSpec() + x.getUnit(), Function.identity(),(k1,k2) ->k2));
        CauseRtVO cvo;
        String k;
        for (CauseDetailVO vo : list) {
            k = vo.getProjectId() + vo.getMaterialCode() + vo.getMaterialId() + vo.getConstructionDetail() + vo.getSpec() + vo.getUnit();
            if (!maps.containsKey(k)){
                continue;
            }
            cvo = maps.get(k);
            vo.setDutyPersonDetailName(cvo.getDutyPersonDetailName());
            vo.setDutySectionDetail(cvo.getDutySectionDetail());
            vo.setExceedCauseDetail(cvo.getExceedCauseDetail());
            vo.setImprovementMeasureDetail(cvo.getImprovementMeasureDetail());
        }

        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("StandingBook-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refCauseData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CauseVO>> refCauseData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ReviewDetailEntity> page = reviewDetailService.queryPage(param,false);
        IPage<CauseVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), CauseVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> cscec5b-xell-impl-3.0.1-20230303.030542-59-sources.jar: com/ejianc/business/wzxt/controller/StandingBookController.java <==
package com.ejianc.business.wzxt.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.wzxt.bean.ReviewDetailEntity;
import com.ejianc.business.wzxt.service.ICauseService;
import com.ejianc.business.wzxt.service.IReviewDetailService;
import com.ejianc.business.wzxt.vo.CauseDetailVO;
import com.ejianc.business.wzxt.vo.CauseRtVO;
import com.ejianc.business.wzxt.vo.CauseVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

import static com.ejianc.framework.skeleton.template.BaseServiceImpl.changeToQueryWrapper;

/**
 * 限额领料台账
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("standingBook")
public class StandingBookController implements Serializable {
	private static final long serialVersionUID = 1L;

    @Autowired
    private IOrgApi orgApi;

    @Autowired
    private IReviewDetailService reviewDetailService;

    @Autowired
    private ICauseService causeService;



    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("spec");
        fuzzyFields.add("materialName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
        } else {
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                    InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        Page<CauseDetailVO> page = new Page<>((long)param.getPageIndex(), (long)param.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(param);
        List<CauseDetailVO> list = reviewDetailService.queryStandingBook(page, wrapper);
        for(int i = 0;i < list.size(); i++){
            list.get(i).setId((long)i);
        }
        param.getParams().remove("wbsId");
        wrapper = changeToQueryWrapper(param);
        List<CauseRtVO> causeList = causeService.querCauseList(wrapper);
        Map<String,CauseRtVO> maps = causeList.stream().collect(Collectors.toMap(x->x.getProjectId() + x.getMaterialCode() + x.getMaterialId() + x.getConstructionDetail() + x.getSpec() + x.getUnit(), Function.identity(),(k1,k2) ->k2));
        CauseRtVO cvo;
        String k;
        for (CauseDetailVO vo : list) {
            k = vo.getProjectId() + vo.getMaterialCode() + vo.getMaterialId() + vo.getConstructionDetail() + vo.getSpec() + vo.getUnit();
            if (!maps.containsKey(k)){
                continue;
            }
            cvo = maps.get(k);
            vo.setDutyPersonDetailName(cvo.getDutyPersonDetailName());
            vo.setDutySectionDetail(cvo.getDutySectionDetail());
            vo.setExceedCauseDetail(cvo.getExceedCauseDetail());
            vo.setImprovementMeasureDetail(cvo.getImprovementMeasureDetail());
        }

        JSONObject res = new JSONObject();
        res.put("records", list);
        res.put("total", page.getTotal());
        res.put("current", page.getCurrent());
        res.put("size", page.getSize());
        res.put("pages", page.getPages());
        return CommonResponse.success("查询列表数据成功！", res);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
        } else {
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                    InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        Page<CauseDetailVO> page = new Page<>((long)param.getPageIndex(), (long)param.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(param);
        List<CauseDetailVO> list = reviewDetailService.queryStandingBookExport(wrapper);
        List<CauseRtVO> causeList = causeService.querCauseList(wrapper);
        Map<String,CauseRtVO> maps = causeList.stream().collect(Collectors.toMap(x->x.getProjectId() + x.getMaterialCode() + x.getMaterialId() + x.getConstructionDetail() + x.getSpec() + x.getUnit(), Function.identity(),(k1,k2) ->k2));
        CauseRtVO cvo;
        String k;
        for (CauseDetailVO vo : list) {
            k = vo.getProjectId() + vo.getMaterialCode() + vo.getMaterialId() + vo.getConstructionDetail() + vo.getSpec() + vo.getUnit();
            if (!maps.containsKey(k)){
                continue;
            }
            cvo = maps.get(k);
            vo.setDutyPersonDetailName(cvo.getDutyPersonDetailName());
            vo.setDutySectionDetail(cvo.getDutySectionDetail());
            vo.setExceedCauseDetail(cvo.getExceedCauseDetail());
            vo.setImprovementMeasureDetail(cvo.getImprovementMeasureDetail());
        }

        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("StandingBook-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refCauseData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CauseVO>> refCauseData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ReviewDetailEntity> page = reviewDetailService.queryPage(param,false);
        IPage<CauseVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), CauseVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
